<?php
/**
 * MIMP Base Class.
 *
 * $Horde: mimp/lib/MIMP.php,v 1.78 2007/11/14 04:38:06 slusarz Exp $
 *
 * Copyright 1999-2007 The Horde Project (http://www.horde.org/)
 *
 * See the enclosed file COPYING for license information (GPL). If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * @author  Chuck Hagenbuch <chuck@horde.org>
 * @package MIMP
 */
class MIMP {

    /**
     * Take a Horde_Mobile_card and add global MIMP menu items.
     *
     * @param Horde_Mobile_linkset &$menu  The menu linkset, with page-specific
     *                                     options already filled in.
     */
    function addMIMPMenu(&$menu)
    {
        $items = array();
        if (($GLOBALS['imp_mbox']['mailbox'] != 'INBOX') ||
            (strpos($_SERVER['PHP_SELF'], 'mailbox.php') === false &&
             strpos($_SERVER['PHP_SELF'], 'message.php') === false)) {
            $items[MIMP::generateMIMPUrl('mailbox.php', 'INBOX')] = _("Inbox");
        }
        if (strpos($_SERVER['PHP_SELF'], 'compose.php') === false) {
            $items[Util::addParameter(Horde::url(MIMP_WEBROOT . 'compose.php'), 'u', base_convert(microtime() . mt_rand(), 10, 36))] = _("Compose");
        }
        if (strpos($_SERVER['PHP_SELF'], 'folders.php') === false) {
            $items[Horde::url(MIMP_WEBROOT . 'folders.php')] = _("Folders");
        }
        // @TODO - Options for mobile browsers
        // if ($options_link = Horde::getServiceLink('options', 'mimp')) {
        //     $items[Util::addParameter($options_link, 'mobile', 1, false)] = _("Options");
        // }
        $logout_link = IMP::getLogoutUrl();
        if (!empty($logout_link)) {
            $items[Auth::addLogoutParameters($logout_link, AUTH_REASON_LOGOUT)] = _("Log out");
        }

        foreach ($items as $link => $label) {
            $menu->add(new Horde_Mobile_link($label, $link));
        }
    }

    /**
     * Wrapper around IMP_Folder::flist() which generates the body of a
     * &lt;select&gt; form input from the generated folder list. The
     * &lt;select&gt; and &lt;/select&gt; tags are NOT included in the output
     * of this function.
     *
     * @param string $heading   An optional string to use as the label for
     *                          an empty-value option at the top of the list
     * @param boolean $abbrev   If true, abbreviate long mailbox names by
     *                          replacing the middle of the name with '...'.
     * @param array $filter     An array of mailboxes to ignore. If the
     *                          first element in the array is null,
     *                          then the mailbox will be shown in the
     *                          resulting list, but there will be an empty
     *                          value argument (i.e. non-selectable).
     * @param string $selected  The mailbox to have selected by default.
     *
     * @return string  A string containg <option> elements for each mailbox in
     *                 the list.
     */
    function flistSelect($heading = '', $abbrev = true, $filter = array(),
                         $selected = null)
    {
        require_once 'Horde/Text.php';
        require_once IMP_BASE . '/lib/Folder.php';

        $imp_folder = &IMP_Folder::singleton();

        /* Don't filter here - since we are going to parse through every
         * member of the folder list below anyway, we can filter at that time.
         * This allows us the have a single cached value for the folder list
         * rather than a cached value for each different mailbox we may
         * visit. */
        $mailboxes = $imp_folder->flist_MIMP();
        $text = '';

        if (strlen($heading) > 0) {
            $text .= '<option value="">' . $heading . "</option>\n";
        }

        /* Add the list of mailboxes to the lists. */
        $showmbox = false;
        if (!empty($filter) && ($filter[0] === null)) {
            $showmbox = true;
            array_shift($filter);
        }

        $filter = array_flip($filter);
        foreach ($mailboxes as $mbox) {
            if (isset($filter[$mbox['val']]) && !$showmbox) {
                continue;
            }

            $val = isset($filter[$mbox['val']]) ? '' : htmlspecialchars($mbox['val']);
            $sel = ($mbox['val'] && ($mbox['val'] === $selected)) ? ' selected="selected"' : '';
            $label = ($abbrev) ? $mbox['abbrev'] : $mbox['label'];
            $text .= sprintf('<option value="%s"%s>%s</option>%s', $val, $sel, Text::htmlSpaces($label), "\n");
        }

        return $text;
    }

    /**
     * Generates a URL with necessary mailbox/index information for MIMP.
     *
     * @param string $page      Page name to link to.
     * @param string $mailbox   The base mailbox to use on the linked page.
     * @param string $index     The index to use on the linked page.
     * @param string $tmailbox  The mailbox associated with $index.
     *
     * @return string  URL to $page with any necessary mailbox information
     *                 added to the parameter list of the URL.
     */
    function generateMIMPUrl($page, $mailbox, $index = null, $tmailbox = null)
    {
        return Util::addParameter(Horde::url(MIMP_WEBROOT . $page), IMP::getIMPMboxParameters($mailbox, $index, $tmailbox));
    }

    /**
     * Returns the appropriate link to call the message composition screen.
     *
     * @since MIMP 1.1
     *
     * @param mixed $args   List of arguments to pass to compose.php. If this
     *                      is passed in as a string, it will be parsed as a
     *                      toaddress?subject=foo&cc=ccaddress (mailto-style)
     *                      string.
     * @param array $extra  Hash of extra, non-standard arguments to pass to
     *                      compose.php.
     *
     * @return string  The link to the message composition screen.
     */
    function composeLink($args = array(), $extra = array())
    {
        return Util::addParameter(Horde::applicationUrl('compose.php'), IMP::composeLinkArgs($args, $extra));
    }

}
