<?php
/**
 * Mailbox display page.
 *
 * Parameters:
 *   'a' = actionID
 *   'p' = page
 *   's' = start
 *
 * $Horde: mimp/mailbox.php,v 1.73 2007/11/14 04:38:05 slusarz Exp $
 *
 * Copyright 1999-2007 The Horde Project (http://www.horde.org/)
 *
 * See the enclosed file COPYING for license information (GPL). If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * @author Chuck Hagenbuch <chuck@horde.org>
 */

@define('MIMP_BASE', dirname(__FILE__));
require_once MIMP_BASE . '/lib/base.php';
require_once IMP_BASE . '/lib/Mailbox.php';
require_once 'Horde/MIME.php';

/* Set the current time zone. */
NLS::setTimeZone();

/* Run through the action handlers */
$actionID = Util::getFormData('a');
switch ($actionID) {
// 'm' = message missing
case 'm':
    $notification->push(_("There was an error viewing the requested message."), 'horde.error');
    break;

// 'e' = expunge mailbox
case 'e':
    require_once IMP_BASE . '/lib/Message.php';
    $imp_message = new IMP_Message();
    $imp_message->expungeMailbox(array($imp_mbox['mailbox'] => 1));
    break;
}

/* Initialize the user's identities. */
require_once 'Horde/Identity.php';
$identity = &Identity::singleton(array('imp', 'imp'));

/* Get the base URL for this page. */
$mailbox_url = MIMP::generateMIMPUrl('mailbox.php', $imp_mbox['mailbox']);

/* Build the list of messages in the mailbox. */
$imp_mailbox = &IMP_Mailbox::singleton($imp_mbox['mailbox']);
$pageOb = $imp_mailbox->buildMailboxPage(Util::getFormData('p'), Util::getFormData('s'));

/* Generate page links. */
$pages_first = $pages_prev = $pages_last = $pages_next = null;
if ($pageOb->page != 1) {
    $pages_first = new Horde_Mobile_link(_("First Page"), Util::addParameter($mailbox_url, 'p', 1));
    $pages_prev = new Horde_Mobile_link(_("Previous Page"), Util::addParameter($mailbox_url, 'p', $pageOb->page - 1));
}
if ($pageOb->page != $pageOb->pagecount) {
    $pages_next = new Horde_Mobile_link(_("Next Page"), Util::addParameter($mailbox_url, 'p', $pageOb->page + 1));
    $pages_last = new Horde_Mobile_link(_("Last Page"), Util::addParameter($mailbox_url, 'p', $pageOb->pagecount));
}

/* Generate mailbox summary string. */
$msg_count = (!empty($pageOb->end))
    ? sprintf(_("%d to %d of %d"), $pageOb->begin, $pageOb->end, $pageOb->msgcount)
    : sprintf(_("No Messages"));

$charset = NLS::getCharset();
$curr_time = time();
$curr_time -= $curr_time % 60;
$msgs = array();
$sortby = $prefs->getValue('sortby');

require_once IMP_BASE . '/lib/UI/Mailbox.php';
$imp_ui = new IMP_UI_Mailbox($imp_mbox['mailbox'], $charset, $identity);

/* Build the array of message information. */
$mailboxOverview = $imp_mailbox->getMailboxArray(range($pageOb->begin, $pageOb->end));
if ($sortby == SORTTHREAD) {
    $threadob = $imp_mailbox->getThreadOb();
}

foreach ($mailboxOverview as $msgIndex => $ob) {
    /* Initialize the header fields. */
    $msg = array(
        'number' => $ob->msgno,
        'status' => ''
    );

    /* Format the from header. */
    $from_res = $imp_ui->getFrom($ob);
    $msg['from'] = $from_res['from'];
    if (String::length($msg['from']) > $mimp_conf['mailbox']['max_from_chars']) {
        $msg['from'] = String::substr($msg['from'], 0, $mimp_conf['mailbox']['max_from_chars']) . '...';
    }

    $msg['subject'] = (!empty($ob->subject))
        ? $imp_ui->getSubject($ob->subject)
        : _("[No Subject]");

    if ($sortby == SORTTHREAD) {
        $maxlen = max($mimp_conf['mailbox']['max_subj_chars'] - 3 * $threadob->getThreadIndent($ob->uid), 5);
        if (String::length($msg['subject']) > $maxlen) {
            $msg['subject'] = String::substr($msg['subject'], 0, $maxlen) . '...';
        }
    } else {
        if (String::length($msg['subject']) > $mimp_conf['mailbox']['max_subj_chars']) {
            $msg['subject'] = String::substr($msg['subject'], 0, $mimp_conf['mailbox']['max_subj_chars']) . '...';
        }
    }

    /* Generate the target link. */
    $target = MIMP::generateMIMPUrl('message.php', $imp_mbox['mailbox'], $ob->uid, $ob->mailbox);

    /* Get flag information. */
    if ($_SESSION['imp']['base_protocol'] != 'pop3') {
        if (!empty($ob->to) && $identity->hasAddress(IMP::bareAddress($ob->to))) {
            $msg['status'] .= '+';
        }
        if (!$ob->seen) {
            $msg['status'] .= 'N';
        }
        if ($ob->answered) {
            $msg['status'] .= 'r';
        }
        if ($ob->draft) {
            $target = MIMP::composeLink(array(), array('a' => 'd', 'thismailbox' => $imp_mbox['mailbox'], 'index' => $ob->uid, 'bodypart' => 1));
        }
        if ($ob->flagged) {
            $msg['status'] .= 'I';
        }
        if ($ob->deleted) {
            $msg['status'] .= 'D';
        }
    }

    $msg['target'] = $target;
    $msgs[] = $msg;
}

$mailbox = Util::addParameter($mailbox_url, 'p', $pageOb->page);
$items = array($mailbox => _("Refresh"));

/* Determine if we are going to show the Hide/Purge Deleted Message links. */
if (!$prefs->getValue('use_trash') &&
    !$prefs->getValue('use_vtrash') &&
    !$GLOBALS['imp_search']->isVINBOXFolder()) {
    $items[Util::addParameter($mailbox, 'a', 'e')] = _("Purge Deleted");
}

/* Create mailbox menu. */
$menu = new Horde_Mobile_card('o', _("Menu"));
$mset = &$menu->add(new Horde_Mobile_linkset());

foreach ($items as $link => $label) {
    $mset->add(new Horde_Mobile_link($label, $link));
}

$nav = array('pages_first', 'pages_prev', 'pages_next', 'pages_last');
foreach ($nav as $n) {
    if (Util::nonInputVar($n)) {
        $mset->add($$n);
    }
}

MIMP::addMIMPMenu($mset);
$title = IMP::getLabel($imp_mbox['mailbox']);
$m->set('title', $title);
require MIMP_TEMPLATES . '/mailbox/mailbox.inc';
